Module protocol

Module protocol 

SOME/IP protocol primitives: headers, messages, return codes, and service discovery.

Modules

byte_order
sd
Service Discovery
tp
SOME/IP-TP

Structs

Header
SOME/IP header
HeaderView
Zero-copy view into a 16-byte SOME/IP header in a buffer.
Message
A SOME/IP message consisting of a Header and a payload.
MessageId
Newtype for a message ID. The Message ID is a 32-bit identifier that is unique for each message. It encodes both the service ID and the method ID. Message IDs are assumed to be unique for an entire vehicle network.
MessageTypeField
Newtype for message type field The field encodes the message type and the TP flag. The TP flag indicates that the message is a SOME/IP TP message.
MessageView
Zero-copy view into a complete SOME/IP message (header + payload).

Enums

Error
Errors that can occur when encoding, decoding, or validating SOME/IP messages.
MessageType
Message types of a SOME/IP message.
ReturnCode
Return code contained in a SOME/IP header.