Module sd

Module sd 

Service Discovery

Structs

EntryIter
Iterator over 16-byte SD entries in a validated buffer. Entries are guaranteed valid (validated upfront in SdHeaderView::parse).
EntryView
Zero-copy view into a 16-byte SD entry in a buffer.
EventGroupEntry
An SD entry for event group operations (subscribe / subscribe-ack).
Flags
Flags byte in the SD protocol.
Header
An SD header that borrows its entries and options slices.
OptionIter
Iterator over variable-length SD options in a validated buffer. Options are guaranteed valid (validated upfront in SdHeaderView::parse).
OptionView
Zero-copy view into a variable-length SD option in a buffer.
OptionsCount
Packed pair of 4-bit option run counts (first and second options run).
SdHeaderView
Zero-copy view into an SD header payload.
ServiceEntry
An SD entry for service operations (find / offer / stop-offer).

Enums

Entry
A decoded SD entry, wrapping a ServiceEntry or EventGroupEntry.
EntryType
The type of an SD entry.
Error
Errors that can occur when parsing or validating SOME/IP-SD messages.
OptionType
The type of an SD option.
Options
A decoded SD option.
TransportProtocol
Transport protocol used in SD endpoint options.

Constants

MAX_CONFIGURATION_STRING_LENGTH
Maximum length of an SD configuration option string in bytes.
MESSAGE_ID_VALUE
SOME/IP Message ID for service discovery messages (0xFFFF_8100).
MULTICAST_IP
Standard SOME/IP-SD multicast group address (239.255.0.255).
MULTICAST_PORT
Standard SOME/IP-SD port (30490).

Functions

extract_ipv4_endpoint
Extract the first IpV4Endpoint address from a slice of owned options.