Options

Enum Options 

pub enum Options {
    Configuration {
        configuration_string: Vec<u8, MAX_CONFIGURATION_STRING_LENGTH>,
    },
    LoadBalancing {
        priority: u16,
        weight: u16,
    },
    IpV4Endpoint {
        ip: Ipv4Addr,
        protocol: TransportProtocol,
        port: u16,
    },
    IpV6Endpoint {
        ip: Ipv6Addr,
        protocol: TransportProtocol,
        port: u16,
    },
    IpV4Multicast {
        ip: Ipv4Addr,
        protocol: TransportProtocol,
        port: u16,
    },
    IpV6Multicast {
        ip: Ipv6Addr,
        protocol: TransportProtocol,
        port: u16,
    },
    IpV4SD {
        ip: Ipv4Addr,
        protocol: TransportProtocol,
        port: u16,
    },
    IpV6SD {
        ip: Ipv6Addr,
        protocol: TransportProtocol,
        port: u16,
    },
}
A decoded SD option.

Variants



Configuration

A configuration key-value string.

Fields

configuration_string: Vec<u8, MAX_CONFIGURATION_STRING_LENGTH>

The raw configuration string bytes.



LoadBalancing

Load balancing parameters.

Fields

priority: u16

The priority value.

weight: u16

The weight value.



IpV4Endpoint

An IPv4 endpoint.

Fields

ip: Ipv4Addr

The IPv4 address.

protocol: TransportProtocol

The transport protocol (UDP or TCP).

port: u16

The port number.



IpV6Endpoint

An IPv6 endpoint.

Fields

ip: Ipv6Addr

The IPv6 address.

protocol: TransportProtocol

The transport protocol (UDP or TCP).

port: u16

The port number.



IpV4Multicast

An IPv4 multicast address.

Fields

ip: Ipv4Addr

The IPv4 multicast address.

protocol: TransportProtocol

The transport protocol (UDP or TCP).

port: u16

The port number.



IpV6Multicast

An IPv6 multicast address.

Fields

ip: Ipv6Addr

The IPv6 multicast address.

protocol: TransportProtocol

The transport protocol (UDP or TCP).

port: u16

The port number.



IpV4SD

An IPv4 SD endpoint.

Fields

ip: Ipv4Addr

The IPv4 address.

protocol: TransportProtocol

The transport protocol (UDP or TCP).

port: u16

The port number.



IpV6SD

An IPv6 SD endpoint.

Fields

ip: Ipv6Addr

The IPv6 address.

protocol: TransportProtocol

The transport protocol (UDP or TCP).

port: u16

The port number.

Implementations

Source

impl Options

pub fn size(&self) -> usize

Returns the total wire size of this option in bytes.

pub fn write<T: Write>(&self, writer: &mut T) -> Result<usize, Error>

Serializes this option to a writer.

Errors

Returns an error if writing to the writer fails.

Panics

Panics if the option size minus 3 exceeds u16::MAX (unreachable in practice).