SdHeaderView

Struct SdHeaderView 

pub struct SdHeaderView<'a> { /* private fields */ }
Zero-copy view into an SD header payload.

Created by SdHeaderView::parse, which fully validates the SD header, entries, and options upfront. This makes the entry and option iterators infallible.

Implementations

Source

impl<'a> SdHeaderView<'a>

pub fn parse(buf: &'a [u8]) -> Result<Self, Error>

Parse and fully validate an SD header from buf.

Validates:

  • Buffer has enough data for flags + entries_size + entries + options_size + options
  • entries_size is a multiple of ENTRY_SIZE (16)
  • All entry type bytes are valid
  • All options have valid types and lengths
Errors

Returns an error if the buffer is too short, entries_size is not a multiple of 16, any entry type byte is invalid, or any option has an invalid type or length.

pub fn flags(&self) -> Flags

Returns the SD flags.

pub fn entries(&self) -> EntryIter<'a>

Returns an iterator over the SD entries.

pub fn options(&self) -> OptionIter<'a>

Returns an iterator over the SD options.

pub fn entry_count(&self) -> usize

Returns the number of entries in this SD header.