pub struct ServiceEntry {
pub index_first_options_run: u8,
pub index_second_options_run: u8,
pub options_count: OptionsCount,
pub service_id: u16,
pub instance_id: u16,
pub major_version: u8,
pub ttl: u32,
pub minor_version: u32,
}Expand description
An SD entry for service operations (find / offer / stop-offer).
Fields
index_first_options_run: u8Index into the options array for the first options run.
index_second_options_run: u8Index into the options array for the second options run.
options_count: OptionsCountNumber of options in each run.
service_id: u16The SOME/IP service ID.
instance_id: u16The SOME/IP instance ID.
major_version: u8The major version of the service interface.
ttl: u32Time-to-live in seconds (24-bit value).
minor_version: u32The minor version of the service interface.
Implementations