MessageTypeField

Struct MessageTypeField 

pub struct MessageTypeField(/* private fields */);
Newtype for message type field The field encodes the message type and the TP flag. The TP flag indicates that the message is a SOME/IP TP message.

Implementations

Source

impl MessageTypeField

pub const fn new(msg_type: MessageType, tp: bool) -> Self

pub const fn new_sd() -> Self

pub fn message_type(&self) -> MessageType

Returns the message type of the message

pub const fn is_tp(&self) -> bool