Crate simple_someip

Crate simple_someip 

Simple SOME/IP (Scalable service-Oriented Middleware over IP)

SOME/IP is an automotive/embedded communication protocol which supports remote procedure calls, event notifications and the underlying serialization/wire format.

This library attempts to expose an ergonomic API for communicating over SOME/IP. This includes encoding/decoding messages, handling the underlying transport, and providing traits to kickstart the development of client/server applications.

This library is based on the Open SOME/IP Specification.

Design

References

Modules

e2e
E2E (End-to-End) protection for SOME/IP payloads.
protocol
traits

Enums

Error

Constants

SD_MESSAGE_ID_VALUE
Message id for SOME/IP service discovery messages
SD_MULTICAST_IP
SD_MULTICAST_PORT