Simple SOME/IP (Scalable service-Oriented Middleware over IP)
SOME/IP is an automotive/embedded communication protocol which supports remote procedure calls, event notifications and the underlying serialization/wire format.
This library attempts to expose an ergonomic API for communicating over SOME/IP. This includes encoding/decoding messages, handling the underlying transport, and providing traits to kickstart the development of client/server applications.
This library is based on the Open SOME/IP Specification.
Design
References
Modules
Enums
Constants
- SD_
MESSAGE_ ID_ VALUE - Message id for SOME/IP service discovery messages
- SD_
MULTICAST_ IP - SD_
MULTICAST_ PORT