Module protocol

Module protocol 

Modules

sd
Service Discovery
tp
SOME/IP-TP

Structs

Header
SOME/IP header
Message
MessageId
Newtype for a message ID. The Message ID is a 32-bit identifier that is unique for each message. It encodes both the service ID and the method ID. Message IDs are assumed to be unique for an entire vehicle network.
MessageTypeField
Newtype for message type field The field encodes the message type and the TP flag. The TP flag indicates that the message is a SOME/IP TP message.

Enums

Error
MessageType
Message types of a SOME/IP message.
ReturnCode
Return code contained in a SOME/IP header.