Module protocol
simple_
someip
0.2.0
Module protocol
Module Items
Modules
Structs
Enums
In crate simple_
someip
simple_someip
Module
protocol
Modules

sd
Service Discovery
tp
SOME/IP-TP
Structs

Header
SOME/IP header
Message
Message
Id
Newtype for a message ID. The Message ID is a 32-bit identifier that is unique for each message. It encodes both the service ID and the method ID. Message IDs are assumed to be unique for an entire vehicle network.
Message
Type
Field
Newtype for message type field The field encodes the message type and the TP flag. The TP flag indicates that the message is a SOME/IP TP message.
Enums

Error
Message
Type
Message types of a SOME/IP message.
Return
Code
Return code contained in a SOME/IP header.