Error

Enum Error 

#[non_exhaustive]
pub enum Error { Io(ErrorKind), Incomplete(Incomplete), Trailing(TrailingBytes), InsufficientBuffer(InsufficientBuffer), InvalidProtocolVersion(u8), InvalidMessageTypeField(u8), InvalidReturnCode(u8), InvalidLength(u32), UnsupportedMessageID(MessageId), Sd(Error), }
Errors that can occur when encoding, decoding, or validating SOME/IP messages.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(ErrorKind)

An I/O error occurred while reading or writing bytes.



Incomplete(Incomplete)

Input ended before the expected number of bytes could be read.



Trailing(TrailingBytes)

Bytes remained after a value that should have consumed the whole buffer.



InsufficientBuffer(InsufficientBuffer)

An output slice was too small for the bytes an encode needed to write.



InvalidProtocolVersion(u8)

The protocol version field contains an unsupported value.



InvalidMessageTypeField(u8)

The message type field contains an unrecognized value.



InvalidReturnCode(u8)

The return code field contains an unrecognized value.



InvalidLength(u32)

The SOME/IP length field was smaller than the 8-byte minimum (request_id..return_code).



UnsupportedMessageID(MessageId)

The message ID is not supported by the payload implementation.



Sd(Error)

A service discovery (SD) error occurred.