Service Discovery
Structs
- Entry
Iter - Iterator over 16-byte SD entries in a validated buffer.
Entries are guaranteed valid (validated upfront in
SdHeaderView::parse). - Entry
View - Zero-copy view into a 16-byte SD entry in a buffer.
- Event
Group Entry - An SD entry for event group operations (subscribe / subscribe-ack).
- Flags
- Flags byte in the SD protocol.
- Header
- An SD header that borrows its entries and options slices.
- Option
Iter - Iterator over variable-length SD options in a validated buffer.
Options are guaranteed valid (validated upfront in
SdHeaderView::parse). - Option
View - Zero-copy view into a variable-length SD option in a buffer.
- Options
Count - Packed pair of 4-bit option run counts (first and second options run).
- SdHeader
View - Zero-copy view into an SD header payload.
- Service
Entry - An SD entry for service operations (find / offer / stop-offer).
Enums
- Entry
- A decoded SD entry, wrapping a
ServiceEntryorEventGroupEntry. - Entry
Type - The type of an SD entry.
- Error
- Errors that can occur when parsing or validating SOME/IP-SD messages.
- Option
Type - The type of an SD option.
- Options
- A decoded SD option.
- Transport
Protocol - Transport protocol used in SD endpoint options.
Constants
- MAX_
CONFIGURATION_ STRING_ LENGTH - Maximum length of an SD configuration option string in bytes.
- MESSAGE_
ID_ VALUE - SOME/IP Message ID for service discovery messages (
0xFFFF_8100). - MULTICAST_
IP - Standard SOME/IP-SD multicast group address (239.255.0.255).
- MULTICAST_
PORT - Standard SOME/IP-SD port (30490).
Functions
- extract_
ipv4_ endpoint - Extract the first
IpV4Endpointaddress from a slice of owned options.