pub enum Entry {
FindService(ServiceEntry),
OfferService(ServiceEntry),
StopOfferService(ServiceEntry),
SubscribeEventGroup(EventGroupEntry),
SubscribeAckEventGroup(EventGroupEntry),
}Expand description
A decoded SD entry, wrapping a ServiceEntry or EventGroupEntry.
Variants
FindService(ServiceEntry)
Find a service.
OfferService(ServiceEntry)
Offer a service.
StopOfferService(ServiceEntry)
Stop offering a service.
SubscribeEventGroup(EventGroupEntry)
Subscribe to an event group.
SubscribeAckEventGroup(EventGroupEntry)
Acknowledge an event group subscription.
Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn first_options_count(&self) -> u8
pub fn first_options_count(&self) -> u8
Returns the number of options in the first options run.
Sourcepub fn second_options_count(&self) -> u8
pub fn second_options_count(&self) -> u8
Returns the number of options in the second options run.
Sourcepub fn total_options_count(&self) -> u8
pub fn total_options_count(&self) -> u8
Returns the total number of options across both runs.