pub struct SdHeaderView<'a> { /* private fields */ }Expand description
Zero-copy view into an SD header payload.
Created by SdHeaderView::parse, which fully validates the SD header,
entries, and options upfront. This makes the entry and option iterators
infallible.
Implementations
Sourceimpl<'a> SdHeaderView<'a>
impl<'a> SdHeaderView<'a>
Sourcepub fn parse(buf: &'a [u8]) -> Result<Self, Error>
pub fn parse(buf: &'a [u8]) -> Result<Self, Error>
Parse and fully validate an SD header from buf.
Validates:
- Buffer has enough data for flags +
entries_size+ entries +options_size+ options entries_sizeis a multiple ofENTRY_SIZE(16)- All entry type bytes are valid
- All options have valid types and lengths
Errors
Returns an error if the buffer is too short, entries_size is not a multiple of 16,
any entry type byte is invalid, or any option has an invalid type or length.
Sourcepub fn options(&self) -> OptionIter<'a> ⓘ
pub fn options(&self) -> OptionIter<'a> ⓘ
Returns an iterator over the SD options.
Sourcepub fn entry_count(&self) -> usize
pub fn entry_count(&self) -> usize
Returns the number of entries in this SD header.