pub struct Header {
pub message_id: MessageId,
pub length: u32,
pub request_id: u32,
pub protocol_version: u8,
pub interface_version: u8,
pub message_type: MessageTypeField,
pub return_code: ReturnCode,
}Expand description
SOME/IP header
Fields
message_id: MessageIdMessage ID, encoding service ID and method ID
length: u32Length of the message in bytes, starting at the request Id Total length of the message is therefore length + 8
request_id: u32SOME/IP Request ID (4 bytes): Client ID [31:16] + Session ID [15:0].
protocol_version: u8interface_version: u8message_type: MessageTypeFieldreturn_code: ReturnCodeImplementations
Sourceimpl Header
impl Header
Sourcepub fn upper_header_bytes(&self) -> [u8; 8]
pub fn upper_header_bytes(&self) -> [u8; 8]
Return the 8-byte “upper header” used by E2E UPPER-HEADER-BITS-TO-SHIFT.
Layout (big-endian): request_id(4) + protocol_version(1) + interface_version(1)
+ message_type(1) + return_code(1)
Note: request_id is the full 4-byte SOME/IP Request ID field
(Client ID [31:16] + Session ID [15:0]), not just the 2-byte Session ID.
pub fn new_sd(request_id: u32, sd_header_size: usize) -> Self
pub const fn is_sd(&self) -> bool
pub const fn payload_size(&self) -> usize
pub fn set_request_id(&mut self, request_id: u32)