Message

Struct Message 

pub struct Message<PayloadDefinition> { /* private fields */ }
A SOME/IP message consisting of a Header and a payload.

Implementations

Source

impl<PayloadDefinition: PayloadWireFormat> Message<PayloadDefinition>

pub const fn new(header: Header, payload: PayloadDefinition) -> Self

Creates a new message from a header and payload.

pub fn new_sd( request_id: u32, sd_header: &<PayloadDefinition as PayloadWireFormat>::SdHeader, ) -> Self

Creates a new SOME/IP-SD message from a request ID and SD header.

pub const fn header(&self) -> &Header

Returns a reference to the message header.

pub const fn is_sd(&self) -> bool

Returns true if this is a SOME/IP-SD message.

pub const fn set_request_id(&mut self, request_id: u32)

Sets the request ID in the header.

pub fn sd_header( &self, ) -> Option<&<PayloadDefinition as PayloadWireFormat>::SdHeader>

Returns the SD header if this is an SD message, or None otherwise.

pub const fn payload(&self) -> &PayloadDefinition

Returns a reference to the payload.

pub const fn payload_mut(&mut self) -> &mut PayloadDefinition

Returns a mutable reference to the payload.